@@ -60,6 +60,7 @@ class SdkConfig(BaseModel):
     default_dir: Optional[str]
     mds_host: Optional[str]
     wp_host: Optional[str]
+    verify_ssl: Optional[bool]
 
 
 class Config(object):
@@ -75,6 +76,7 @@ class Config(object):
         self.default_dir = config.get("default_dir") or settings.DEFAULT_DIR
         self.mds_host = config.get("mds_host") or settings.MDS_HOST
         self.wp_host = config.get("wp_host") or settings.WP_HOST
+        self.verify_ssl = config.get("verify_ssl") or True
 
 
 class ConfigProvider(object):
@@ -103,6 +105,7 @@ class EnvarProvider(ConfigProvider):
     MDS_HOST = "MDS_HOST"
     WP_HOST = "WP_HOST"
     DEFAULT_DIR = "DEFAULT_DIR"
+    VERIFY_SSL = "VERIFY_SSL"
 
     def __init__(
         self, environ: os._Environ = None, mapping: Dict[str, str] = None
@@ -123,6 +126,7 @@ class EnvarProvider(ConfigProvider):
                 "mds_host": self.MDS_HOST,
                 "wp_host": self.WP_HOST,
                 "default_dir": self.DEFAULT_DIR,
+                "verify_ssl": self.VERIFY_SSL,
             }
 
         return {
@@ -133,6 +137,7 @@ class EnvarProvider(ConfigProvider):
             "mds_host": mapping.get("mds_host", self.MDS_HOST),
             "wp_host": mapping.get("wp_host", self.WP_HOST),
             "default_dir": mapping.get("default_dir", self.DEFAULT_DIR),
+            "verify_ssl": mapping.get("verify_ssl", self.VERIFY_SSL),
         }
 
     def extract_config(self) -> Optional[Dict[str, str]]:
@@ -162,6 +167,12 @@ class EnvarProvider(ConfigProvider):
         mds_host = self.environ.get(self._mapping["mds_host"], "")
         wp_host = self.environ.get(self._mapping["wp_host"], "")
 
+        verify_ssl = self.environ.get(self._mapping["verify_ssl"], "True") in [
+            "True",
+            "true",
+            "",
+        ]
+
         return {
             "canalyst_api_key": canalyst_api_key,
             "s3_access_key_id": s3_access_key_id,
@@ -170,6 +181,7 @@ class EnvarProvider(ConfigProvider):
             "default_dir": default_dir,
             "mds_host": mds_host,
             "wp_host": wp_host,
+            "verify_ssl": verify_ssl,
         }
 
 
@@ -235,6 +247,8 @@ class FileProvider(ConfigProvider):
         if not config.get("canalyst_s3_key"):
             raise ConfigException("S3 secret key was not provided")
 
+        verify_ssl = config.get("verify_ssl", "True") in ["true", "True", ""]
+
         return {
             "canalyst_api_key": config.get("canalyst_api_key"),
             "s3_access_key_id": config.get("canalyst_s3_id"),
@@ -243,4 +257,5 @@ class FileProvider(ConfigProvider):
             "mds_host": config.get("mds_host", ""),
             "wp_host": config.get("wp_host", ""),
             "default_dir": config.get("default_dir", ""),
+            "verify_ssl": verify_ssl,
         }
