@@ -18,16 +18,16 @@ class Connection:
         """
         Return a Model with configuration
         """
-        return Model(config=self.config, *args, **kwargs)
+        return Model(*args, **dict(kwargs, config=self.config))
 
     def get_model_map(self, *args: Any, **kwargs: Any) -> ModelMap:
         """
         Return a ModelMap with configuration
         """
-        return ModelMap(config=self.config, *args, **kwargs)
+        return ModelMap(*args, **dict(kwargs, config=self.config))
 
-    def get_model_set(self, *args, **kwargs) -> ModelSet:
+    def get_model_set(self, *args: Any, **kwargs: Any) -> ModelSet:
         """
         Return a ModelSet with configuration
         """
-        return ModelSet(config=self.config, *args, **kwargs)
+        return ModelSet(*args, **dict(kwargs, config=self.config))
