@@ -4,6 +4,7 @@ Utilities module
 from enum import Enum
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 import pandas as pd
+from canalyst_candas.configuration.exceptions import ConfigException
 from python_graphql_client import GraphqlClient
 import numpy as np
 from urllib.parse import quote_plus
@@ -26,6 +27,7 @@ import pickle
 
 from canalyst_candas.configuration.config import Config, resolve_config
 import urllib3
+from pathlib import Path
 
 urllib3.disable_warnings()
 
@@ -43,6 +45,28 @@ SCENARIO_URL_FORECAST = (
 
 HISTORICAL_PERIODS_TO_FETCH = 24
 
+BRAND_CONFIG_DEFAULTS = {
+    "chart_plot_colors": [
+        "#E2E3E3",
+        "#FFD200",
+        "#367ADD",
+        "#8CE0FD",
+        "#E52B26",
+        "#F8623F",
+        "#00838F",
+        "#30C08F",
+        "#8EA1FF",
+    ],
+    "figure_bg_color": "#FFFFFF",
+    "vertical_line_color": "#E2E3E3",
+    "ax_spine_color": "#C3C2C3",
+    "title_font_path": "canalyst_candas/fonts/Barlow-SemiBold.ttf",
+    "body_font_path": "canalyst_candas/fonts/Roboto-Regular.ttf",
+    "chart_bg_color": "#161B21",
+    "font_color": "#000",
+    "logo_path": os.getcwd() + "/canalyst_candas/images/logo.png",
+}
+
 
 class CsvDataKeys(Enum):
     FORECAST_DATA = "forecast-data"
@@ -602,7 +626,7 @@ def get_csin_from_ticker(ticker, auth_headers, mds_host=settings.MDS_HOST):
     return csin
 
 
-def get_excel_model(ticker, config, download_dir=""):
+def get_excel_model(config, ticker="", download_dir=""):
     """
     Retrieve Excel model from Web Portal
     """
@@ -652,17 +676,28 @@ def get_excel_model(ticker, config, download_dir=""):
     ]
     file_ticker = ticker.split(" ")[0]
     file_name = data["data"]["modelSeries"]["latestModel"]["name"]
+    backup_name = file_name.replace(".xlsx", "")
+
     file_name = f"{default_dir}/DATA/{file_ticker}/{file_name}.xlsx"
 
-    if path.exists(file_name):
-        return file_name
+    ext = str(datetime.datetime.now())
+    ext = ext.replace(" ", "_")
+    ext = ext.replace(":", "_")
+    ext = ext.replace("-", "_")
+
+    backup_name = f"{default_dir}/DATA/{file_ticker}/{backup_name}.{ext}"
 
     os.makedirs(f"{default_dir}/DATA/{file_ticker}/", exist_ok=True)
-    print("Saved to: " + file_name)
+
+    if path.exists(file_name):
+        os.rename(file_name, backup_name)
+        print("Backup to: " + backup_name)
+
     r = requests.get(url, headers=auth_headers, verify=False)
 
     with open(file_name, "wb") as f:
         f.write(r.content)
+    print("Saved to: " + file_name)
 
     return
 
@@ -1576,3 +1611,82 @@ COMP_LISTS["SAAS"] = [
     "ZI US",
     "ZS US",
 ]
+
+
+def get_chart_brand_config(
+    chart_colors: List[str] = BRAND_CONFIG_DEFAULTS["chart_plot_colors"],
+    figure_bg_color: str = BRAND_CONFIG_DEFAULTS["figure_bg_color"],
+    vertical_line_color: str = BRAND_CONFIG_DEFAULTS["vertical_line_color"],
+    ax_spine_color: str = BRAND_CONFIG_DEFAULTS["ax_spine_color"],
+    title_font_path: str = BRAND_CONFIG_DEFAULTS["title_font_path"],
+    body_font_path: str = BRAND_CONFIG_DEFAULTS["body_font_path"],
+    chart_bg_color: str = BRAND_CONFIG_DEFAULTS["chart_bg_color"],
+    font_color: str = BRAND_CONFIG_DEFAULTS["font_color"],
+    logo_path: str = BRAND_CONFIG_DEFAULTS["logo_path"],
+):
+    """
+    Get a brand config for custom chart branding
+
+    Returns a dict of the complete set of config options.
+    """
+    is_validated = _validate_colors(
+        chart_colors,
+        figure_bg_color,
+        vertical_line_color,
+        ax_spine_color,
+        chart_bg_color,
+    )
+
+    if not is_validated:
+        raise ValueError(
+            "All color values must be in Hex format (e.g #FFF or #FFFFFF)."
+        )
+
+    chart_brand_config = {
+        "chart_plot_colors": chart_colors,
+        "figure_bg_color": figure_bg_color,
+        "chart_bg_color": chart_bg_color,
+        "vertical_line_color": vertical_line_color,
+        "ax_spine_color": ax_spine_color,
+        "title_font_path": title_font_path,
+        "body_font_path": body_font_path,
+        "font_color": font_color,
+        "logo_path": logo_path,
+    }
+
+    return chart_brand_config
+
+
+def _validate_colors(
+    colors,
+    figure_bg_color,
+    vertical_line_color,
+    ax_spine_color,
+    chart_bg_color,
+):
+    """
+    Validate color arguments
+    """
+
+    # Validate arguments
+    check_for_hex = "^#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$"
+
+    if not isinstance(colors, List):
+        return False
+    else:
+        for color in colors:
+            match = re.search(check_for_hex, color)
+            if not match:
+                return False
+
+    match_figure_bg_color = re.search(check_for_hex, figure_bg_color)
+    match_vertical_line_color = re.search(check_for_hex, vertical_line_color)
+    match_ax_spine_color = re.search(check_for_hex, ax_spine_color)
+    match_chart_bg_color = re.search(check_for_hex, chart_bg_color)
+
+    return (
+        match_figure_bg_color
+        and match_vertical_line_color
+        and match_ax_spine_color
+        and match_chart_bg_color
+    )
